#[non_exhaustive]pub enum JsonRepairError {
RepairFailed(String),
DeserializationFailed {
details: String,
},
}Expand description
Error types for tolerant JSON parsing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RepairFailed(String)
The raw text could not be repaired into valid JSON.
DeserializationFailed
The repaired JSON could not be deserialized into the target type.